@@ -159,7 +159,7 @@ public:
     };
 
     EntryInternal::List installedEntries() const {{EntryInternal::List entries;
-    for (const EntryInternal &entry : qAsConst(cachedEntries)) {
+    for (const EntryInternal &entry : std::as_const(cachedEntries)) {
         if (entry.status() == KNS3::Entry::Installed || entry.status() == KNS3::Entry::Updateable) {
             entries.append(entry);
         }
@@ -336,15 +336,15 @@ void parseFeedData(const QDomDocument &doc)
         entry.setUniqueId(feedEntry.id());
 
         entry.setStatus(KNS3::Entry::Invalid);
-        for (const EntryInternal &cachedEntry : qAsConst(cachedEntries)) {
+        for (const EntryInternal &cachedEntry : std::as_const(cachedEntries)) {
             if (entry.uniqueId() == cachedEntry.uniqueId()) {
                 entry = cachedEntry;
                 break;
             }
         }
 
-        // This is a bit of a pickle: atom feeds can have multiple catagories.
-        // but these catagories are not specifically tags...
+        // This is a bit of a pickle: atom feeds can have multiple categories.
+        // but these categories are not specifically tags...
         QStringList entryTags;
         for (int j = 0; j < feedEntry.categories().size(); j++) {
             QString tag = feedEntry.categories().at(j).label();
