@@ -1,23 +1,8 @@
 /*
- * Copyright (C) 2016 Dan Leinir Turthra Jensen <admin@leinir.dk>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    SPDX-FileCopyrightText: 2016 Dan Leinir Turthra Jensen <admin@leinir.dk>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #ifndef ITEMSMODEL_H
 #define ITEMSMODEL_H
@@ -68,7 +53,7 @@ class ItemsModel : public QAbstractListModel
     /**
      * The NewStuffQuickEngine to show items from
      */
-    Q_PROPERTY(QObject* engine READ engine WRITE setEngine NOTIFY engineChanged)
+    Q_PROPERTY(QObject *engine READ engine WRITE setEngine NOTIFY engineChanged)
     /**
      * Whether or not the model is fetching information from a remote location
      * @since 5.65
@@ -76,7 +61,7 @@ class ItemsModel : public QAbstractListModel
     Q_PROPERTY(bool isLoadingData READ isLoadingData NOTIFY isLoadingDataChanged)
 public:
     explicit ItemsModel(QObject *parent = nullptr);
-    virtual ~ItemsModel();
+    ~ItemsModel() override;
 
     enum Roles {
         NameRole = Qt::UserRole + 1,
@@ -108,7 +93,8 @@ public:
         ProviderIdRole,
         SourceRole,
         StatusRole,
-        CommentsModelRole
+        CommentsModelRole,
+        EntryTypeRole
     };
     Q_ENUM(Roles)
     enum ItemStatus {
@@ -118,20 +104,47 @@ public:
         UpdateableStatus,
         DeletedStatus,
         InstallingStatus,
-        UpdatingStatus
+        UpdatingStatus,
     };
     Q_ENUM(ItemStatus)
 
-    QHash< int, QByteArray > roleNames() const override;
-    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
-    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
-    bool canFetchMore(const QModelIndex & parent) const override;
-    void fetchMore(const QModelIndex & parent) override;
+    /**
+     * Represents whether the current entry is an actual catalog entry,
+     * or an entry that represents a set of entries.
+     * @since 5.83
+     */
+    enum EntryType { CatalogEntry = 0, GroupEntry };
+
+    Q_ENUM(EntryType)
+    // The lists in OCS are one-indexed, and that isn't how one usually does things in C++.
+    // Consequently, this enum removes what would seem like magic numbers from the code, and
+    // makes their meaning more explicit.
+    enum LinkId {
+        AutoDetectLinkId = -1,
+        FirstLinkId = 1,
+    };
+    Q_ENUM(LinkId)
+
+    QHash<int, QByteArray> roleNames() const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    bool canFetchMore(const QModelIndex &parent) const override;
+    void fetchMore(const QModelIndex &parent) override;
 
     QObject *engine() const;
     void setEngine(QObject *newEngine);
     Q_SIGNAL void engineChanged();
 
+    /**
+     * Get the index of an entry based on that entry's unique ID
+     * @param providerId The provider inside of which you wish to search for an entry
+     * @param entryId The unique ID within the given provider of the entry you want to know the index of
+     * @return The index of the entry. In case the entry is not found, -1 is returned
+     * @see KNSCore::EntryInternal::uniqueId()
+     * @since 5.79
+     */
+    Q_INVOKABLE int indexOfEntryId(const QString &providerId, const QString &entryId);
+
     /**
      * Whether or not the model is fetching information from a remote location
      * @since 5.65
@@ -151,8 +164,24 @@ public:
      * the function will simply return without performing any actions)
      *
      * @param index The index of the item to install or update
+     * @param linkId The download item to install. If this is -1, it is assumed to be an update with an unknown payload, and a number of heuristics will be
+     * applied by the engine
+     * @see Engine::downloadLinkLoaded implementation for details
+     * @see LinkId
      */
     Q_INVOKABLE void installItem(int index, int linkId);
+    /**
+     * @brief This will request an update of the given item
+     *
+     * There are no side effects of this function if it is called on an item which is not
+     * in an updateable state (that is, nothing will happen if this is called on an item
+     * which is not already installed, or on an installed item which does not have updates
+     * available).
+     *
+     * @param index The index of the item you wish to update
+     * @since 5.69
+     */
+    Q_INVOKABLE void updateItem(int index);
     /**
      * @brief Uninstall an already installed item
      *
@@ -179,10 +208,11 @@ public:
      * @param index The index of the item which has changed
      */
     Q_SIGNAL void entryChanged(int index);
+
 private:
     class Private;
     Private *d;
 };
 Q_DECLARE_METATYPE(ItemsModel::ItemStatus)
 
-#endif//ITEMSMODEL_H
+#endif // ITEMSMODEL_H
